@@ -69,52 +69,10 @@ QString Error::description() const
 
 int Error::typeToDb(Error::Type type)
 {
-    switch (type) {
-    case Error::Type::FeedUpdate:
-        return 0;
-    case Error::Type::MediaDownload:
-        return 1;
-    case Error::Type::MeteredNotAllowed:
-        return 2;
-    case Error::Type::InvalidMedia:
-        return 3;
-    case Error::Type::DiscoverError:
-        return 4;
-    case Error::Type::StorageMoveError:
-        return 5;
-    case Error::Type::SyncError:
-        return 6;
-    case Error::Type::MeteredStreamingNotAllowed:
-        return 7;
-    case Error::Type::NoNetwork:
-        return 8;
-    default:
-        return -1;
-    }
+    return static_cast<int>(type);
 }
 
 Error::Type Error::dbToType(int value)
 {
-    switch (value) {
-    case 0:
-        return Error::Type::FeedUpdate;
-    case 1:
-        return Error::Type::MediaDownload;
-    case 2:
-        return Error::Type::MeteredNotAllowed;
-    case 3:
-        return Error::Type::InvalidMedia;
-    case 4:
-        return Error::Type::DiscoverError;
-    case 5:
-        return Error::Type::StorageMoveError;
-    case 6:
-        return Error::Type::SyncError;
-    case 7:
-        return Error::Type::MeteredStreamingNotAllowed;
-    case 8:
-        return Error::Type::NoNetwork;
-    default:
-        return Error::Type::Unknown;
-    }
+    return Error::Type(value);
 }
