@@ -10,6 +10,7 @@
 #include <QHash>
 #include <QItemSelection>
 #include <QObject>
+#include <QQmlEngine>
 #include <QVariant>
 
 #include "enclosure.h"
@@ -18,6 +19,8 @@
 class DownloadModel : public QAbstractListModel
 {
     Q_OBJECT
+    QML_ELEMENT
+    QML_SINGLETON
 
 public:
     static DownloadModel &instance()
@@ -25,6 +28,11 @@ public:
         static DownloadModel _instance;
         return _instance;
     }
+    static DownloadModel *create(QQmlEngine *engine, QJSEngine *)
+    {
+        engine->setObjectOwnership(&instance(), QQmlEngine::CppOwnership);
+        return &instance();
+    }
 
     QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override;
     QHash<int, QByteArray> roleNames() const override;
